@@ -3,6 +3,7 @@
 
 
 from django.db import models
+from django.core.exceptions import ObjectDoesNotExist
 from django_extensions.db.fields import AutoSlugField
 from mptt.models import MPTTModel, TreeForeignKey
 
@@ -10,8 +11,14 @@ from core_main_app.commons import exceptions as exceptions
 
 
 class Category(MPTTModel):
+    """Category object"""
+
     parent = TreeForeignKey(
-        "self", null=True, on_delete=models.CASCADE, blank=True, related_name="children"
+        "self",
+        null=True,
+        on_delete=models.CASCADE,
+        blank=True,
+        related_name="children",
     )
     name = models.CharField(max_length=50)
     slug = AutoSlugField(max_length=50, overwrite=True, populate_from="name")
@@ -19,7 +26,14 @@ class Category(MPTTModel):
     value = models.CharField(max_length=255)
     refinement = models.ForeignKey("Refinement", on_delete=models.CASCADE)
 
+    class Meta:
+        """Meta"""
+
+        verbose_name_plural = "Categories"
+
     class MPTTMeta(object):
+        """MPTTMeta"""
+
         verbose_name_plural = "categories"
         unique_together = (("name", "slug", "parent"),)
         ordering = ("tree_id", "lft")
@@ -51,7 +65,11 @@ class Category(MPTTModel):
 
         """
         return Category.objects.create(
-            name=name, path=path, value=value, parent=parent, refinement=refinement
+            name=name,
+            path=path,
+            value=value,
+            parent=parent,
+            refinement=refinement,
         )
 
     @staticmethod
@@ -67,13 +85,15 @@ class Category(MPTTModel):
         """
         try:
             return Category.objects.get(pk=category_id)
-        except Category.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
 
     @staticmethod
-    def get_all_categories_by_parent_slug_and_refinement_id(parent_slug, refinement_id):
+    def get_all_categories_by_parent_slug_and_refinement_id(
+        parent_slug, refinement_id
+    ):
         """Get all categories by parent_slug and refinement.
 
         Args:
@@ -87,8 +107,8 @@ class Category(MPTTModel):
             return Category.objects.get(
                 slug__startswith=parent_slug, refinement_id=refinement_id
             ).get_family()
-        except Category.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
 
@@ -102,7 +122,9 @@ class Category(MPTTModel):
         return Category.objects.all()
 
     @staticmethod
-    def get_all_categories_ids_from_name_and_refinement_id(name, refinement_id):
+    def get_all_categories_ids_from_name_and_refinement_id(
+        name, refinement_id
+    ):
         """Get all categories by name and refinement id.
 
         Args:
@@ -116,7 +138,15 @@ class Category(MPTTModel):
             return Category.objects.get(
                 name=name, refinement_id=refinement_id
             ).get_family()
-        except Category.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
+
+    def __str__(self):
+        """Category as string
+
+        Returns:
+
+        """
+        return self.name
