@@ -5,7 +5,7 @@ from core_main_registry_app.components.refinement.models import Refinement
 
 
 def create_and_save(name, xsd_name, template_hash):
-    """ Create and save a refinement.
+    """Create and save a refinement.
 
     Args:
         name:
@@ -23,7 +23,7 @@ def create_and_save(name, xsd_name, template_hash):
 
 
 def get_all():
-    """ Get all refinements.
+    """Get all refinements.
 
     Returns: Refinement collection
 
@@ -32,7 +32,7 @@ def get_all():
 
 
 def get_all_filtered_by_template_hash(template_hash):
-    """ Get all refinements by template hash.
+    """Get all refinements by template hash.
 
     Args:
         template_hash:
@@ -40,11 +40,13 @@ def get_all_filtered_by_template_hash(template_hash):
     Returns: Refinement collection
 
     """
-    return Refinement.get_all_filtered_by_template_hash(template_hash=template_hash)
+    return Refinement.get_all_filtered_by_template_hash(
+        template_hash=template_hash
+    )
 
 
 def check_refinements_already_exist_by_template_hash(template_hash):
-    """ Check if the refinements have already been generated for the template.
+    """Check if the refinements have already been generated for the template.
 
     Args:
         template_hash:
@@ -53,11 +55,13 @@ def check_refinements_already_exist_by_template_hash(template_hash):
         Boolean: True/False
 
     """
-    return Refinement.check_refinements_already_exist_by_template_hash(template_hash)
+    return Refinement.check_refinements_already_exist_by_template_hash(
+        template_hash
+    )
 
 
 def get_by_template_hash_and_by_slug(template_hash, slug):
-    """ Get refinement by template hash and by slug.
+    """Get refinement by template hash and by slug.
 
     Args:
         template_hash:
