@@ -53,9 +53,20 @@ def get_doc(node, values, count_mode):
 
 
 def recursive_node_to_dict(node, values, count_mode):
+    """recursive node to dict.
+
+    Args:
+        node:
+        values:
+        count_mode:
+
+    Returns:
+
+    """
     result = get_doc(node, values, count_mode)
     children = [
-        recursive_node_to_dict(c, values, count_mode) for c in node.get_children()
+        recursive_node_to_dict(c, values, count_mode)
+        for c in node.get_children()
     ]
     if children:
         expand = [c for c in children if c.get("selected", False)]
@@ -67,13 +78,30 @@ def recursive_node_to_dict(node, values, count_mode):
 
 
 def get_tree(nodes, values, count_mode):
+    """get tree.
+
+    Args:
+        nodes:
+        values:
+        count_mode:
+
+    Returns:
+
+    """
     root_nodes = cache_tree_children(nodes)
     return [recursive_node_to_dict(n, values, count_mode) for n in root_nodes]
 
 
 class FancyTreeWidget(Widget):
+    """Fancy Tree Widget"""
+
     def __init__(
-        self, attrs=None, choices=(), queryset=None, select_mode=3, count_mode=False
+        self,
+        attrs=None,
+        choices=(),
+        queryset=None,
+        select_mode=3,
+        count_mode=False,
     ):
         """
 
@@ -83,19 +111,43 @@ class FancyTreeWidget(Widget):
             queryset:
             select_mode:
             count_mode: Add an html element to display counts next to each node (True/False).
+
         """
-        super(FancyTreeWidget, self).__init__(attrs)
+        super().__init__(attrs)
         self.queryset = queryset
         self.select_mode = select_mode
         self.choices = list(choices)
         self.count_mode = count_mode
 
     def value_from_datadict(self, data, files, name):
-        if isinstance(data, (MultiValueDict)):
+        """value from datadict
+
+        Args:
+            data:
+            files:
+            name:
+
+        Returns:
+
+        """
+
+        if isinstance(data, MultiValueDict):
             return data.getlist(name)
         return data.get(name, None)
 
     def render(self, name, value, attrs=None, choices=(), renderer=None):
+        """render
+
+        Args:
+            name:
+            value:
+            attrs:
+            choices:
+            renderer:
+
+        Returns:
+
+        """
         if value is None:
             value = []
         if not isinstance(value, (list, tuple)):
@@ -112,10 +164,13 @@ class FancyTreeWidget(Widget):
             output = ['<div name="%s"></div>' % self.choices.field.label]
             id_attr = ""
         output.append(
-            '<ul style="display: none;" class="fancytree_checkboxes"%s>' % id_attr
+            '<ul style="display: none;" class="fancytree_checkboxes"%s>'
+            % id_attr
         )
         str_values = set([force_text(v) for v in value])
-        for i, (option_value, option_label) in enumerate(chain(self.choices, choices)):
+        for i, (option_value, option_label) in enumerate(
+            chain(self.choices, choices)
+        ):
             if has_id:
                 final_attrs = dict(
                     final_attrs, id="%s_%s" % (attrs["id"], option_value)
@@ -124,11 +179,11 @@ class FancyTreeWidget(Widget):
             else:
                 label_for = ""
 
-            cb = forms.CheckboxInput(
+            checkbox = forms.CheckboxInput(
                 final_attrs, check_test=lambda value: value in str_values
             )
             option_value = force_text(option_value)
-            rendered_cb = cb.render(name, option_value)
+            rendered_cb = checkbox.render(name, option_value)
             option_label = conditional_escape(force_text(option_label))
             output.append(
                 "<li><label%s>%s %s</label></li>"
@@ -142,7 +197,9 @@ class FancyTreeWidget(Widget):
                 "var %s = %s;"
                 % (
                     js_data_var,
-                    json.dumps(get_tree(self.queryset, str_values, self.count_mode)),
+                    json.dumps(
+                        get_tree(self.queryset, str_values, self.count_mode)
+                    ),
                 )
             )
             output.append(
@@ -263,7 +320,8 @@ class FancyTreeWidget(Widget):
         output.append("</script>")
         return mark_safe("\n".join(output))
 
-    class Media(object):
+    class Media:
+        """Media"""
 
         js = ("core_explore_common_app/common/js/tools.js",)
 
