@@ -1,11 +1,12 @@
 """
     Admin views
 """
-import logging
 import json
+import logging
+
 from django.contrib.admin.views.decorators import staff_member_required
-from django.urls import reverse
 from django.http.response import HttpResponseRedirect
+from django.urls import reverse
 from django.utils.html import escape as html_escape
 from django.views.generic import View
 
@@ -14,7 +15,9 @@ from core_main_app.components.template_version_manager import (
     api as template_version_manager_api,
 )
 from core_main_app.utils.rendering import admin_render
-from core_main_registry_app.components.custom_resource import api as custom_resource_api
+from core_main_registry_app.components.custom_resource import (
+    api as custom_resource_api,
+)
 from core_main_registry_app.views.admin.forms import UploadCustomResourcesForm
 
 logger = logging.getLogger("core_main_registry_app.views.admin.views")
@@ -37,8 +40,12 @@ def manage_templates(request):
 
     context = {
         "object_name": "Template",
-        "available": [template for template in templates if not template.is_disabled],
-        "disabled": [template for template in templates if template.is_disabled],
+        "available": [
+            template for template in templates if not template.is_disabled
+        ],
+        "disabled": [
+            template for template in templates if template.is_disabled
+        ],
     }
 
     assets = {}
@@ -61,7 +68,7 @@ class UploadCustomResource(View):
     object_name = "Custom Resources"
 
     def __init__(self, **kwargs):
-        super(UploadCustomResource, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.context = {}
         self.context.update({"object_name": self.object_name})
 
@@ -76,9 +83,9 @@ class UploadCustomResource(View):
 
         if form.is_valid():
             return self._save_custom_resources(request, template_id)
-        else:
-            # Display error from the form
-            return admin_render(request, self.template_name, context=self.context)
+
+        # Display error from the form
+        return admin_render(request, self.template_name, context=self.context)
 
     def _save_custom_resources(self, request, template_id):
         """Saves an XSLT.
@@ -90,20 +97,24 @@ class UploadCustomResource(View):
         """
         try:
             # get the template
-            template = template_api.get(template_id, request=request)
+            template = template_api.get_by_id(template_id, request=request)
 
             # get the file from the form
             upload_file = request.FILES["json_file"].read().decode("utf-8")
 
             data = json.loads(upload_file)
-            custom_resource_api.replace_custom_resources_by_template(template, data)
+            custom_resource_api.replace_custom_resources_by_template(
+                template, data
+            )
 
             return HttpResponseRedirect(
-                reverse("admin:core_main_registry_app_custom_registry")
+                reverse("core-admin:core_main_registry_app_custom_registry")
+            )
+        except Exception as exception:
+            self.context.update({"errors": html_escape(str(exception))})
+            return admin_render(
+                request, self.template_name, context=self.context
             )
-        except Exception as e:
-            self.context.update({"errors": html_escape(str(e))})
-            return admin_render(request, self.template_name, context=self.context)
 
 
 class CustomRegistry(View):
@@ -112,7 +123,9 @@ class CustomRegistry(View):
     def get(self, request, *args, **kwargs):
         data_context_list = []
         global_template_version_manager = (
-            template_version_manager_api.get_global_version_managers(request=request)
+            template_version_manager_api.get_global_version_managers(
+                request=request
+            )
         )
         if len(global_template_version_manager) == 1:
             template_version_manager = list(global_template_version_manager)[0]
@@ -121,16 +134,19 @@ class CustomRegistry(View):
             # for each template versions
             for version in template_version_manager.versions:
                 # get the template
-                template = template_api.get(version, request=request)
+                template = template_api.get_by_id(version, request=request)
                 # get all the template's custom resources
-                custom_resources = custom_resource_api.get_all_by_template(template)
+                custom_resources = custom_resource_api.get_all_by_template(
+                    template
+                )
                 # append to list for the context
                 data_context_list.append(
                     {
                         "template_name": template.display_name,
                         "count": custom_resources.count(),
                         "template_id": str(template.id),
-                        "is_current": current_template_version == str(template.id),
+                        "is_current": current_template_version
+                        == str(template.id),
                     }
                 )
         else:
@@ -142,7 +158,10 @@ class CustomRegistry(View):
             "js": [],
         }
 
-        context = {"objects": data_context_list, "object_name": "Custom Resources"}
+        context = {
+            "objects": data_context_list,
+            "object_name": "Custom Resources",
+        }
 
         return admin_render(
             request,
