@@ -62,3 +62,6 @@ PASSWORD_HASHERS = ("django.contrib.auth.hashers.UnsaltedMD5PasswordHasher",)
 
 USE_TZ = True
 CELERYBEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
+
+MONGODB_INDEXING = False
+MONGODB_ASYNC_SAVE = False
